'\"
'\" Copyright (c) 1993 The Regents of the University of California.
'\" Copyright (c) 1994-1996 Sun Microsystems, Inc.
'\"
'\" See the file "license.terms" for information on usage and redistribution
'\" of this file, and for a DISCLAIMER OF ALL WARRANTIES.
'\" 
'\" SCCS: @(#) nresub.n 1.9 96/08/26 13:00:11
'\" 
.so man.macros
.TH nresub n 3.0 Nre "Nre Package Commands"
.BS
'\" Note:  do not modify the .SH NAME line immediately below!
.SH NAME
nresub \- Perform substitutions based on regular expression pattern matching
.SH SYNOPSIS
\fBpackage require nre ?3.0?\fP
.sp
\fBnresub \fR?\fIswitches\fR? \fIexp string subSpec varName\fR
.sp
\fBnresub -eval \fR?\fIswitches\fR? \fIexp string subSpec varName evalName\fR
.BE

.SH DESCRIPTION
.PP
This command matches the regular expression \fIexp\fR against
\fIstring\fR,
and it copies \fIstring\fR to the variable whose name is
given by \fIvarName\fR.
If there is a match, then while copying \fIstring\fR to \fIvarName\fR
the portion of \fIstring\fR that
matched \fIexp\fR is replaced with \fIsubSpec\fR.
Instead of using the standard regular expression package it uses
the package described in the \fBnrematch\fR man page.
.LP
If the initial arguments to \fBnresub\fR start with \fB\-\fR then
they are treated as switches.  The following switches are
currently supported:
.TP 10
\fB\-all\fR
All ranges in \fIstring\fR that match \fIexp\fR are found and
substitution is performed for each of these ranges.
Without this switch only the first
matching range is found and substituted.
If \fB\-all\fR is specified, then the \fIsubSpec\fR expansion
is handled for each substitution using the information
from the corresponding match.
.TP 10
\fB\-nocase\fR
Upper-case characters in \fIstring\fR will be converted to lower-case
before matching against \fIexp\fR;  however, substitutions specified
by \fIsubSpec\fR use the original unconverted form of \fIstring\fR.
.TP 10
\fB\-eval\fR
Evaluate \fIsubSpec\fR for each successful match of \fIexp\fR
and use the result of evaluation as the
string to replace the text matched by the regular expression.
The text matched by the regular expression can be accessed from
within the \fIsubSpec\fR by extracting it from the \fIevalName\fR variable.
\fBnresub\fR sets the \fIevalName\fR variable to a value after each
successful match of \fIexp\fR. If the \fIexp\fR has no subexpression then
the value is a simple string contained the matched text. Otherwise the
value is a list whose first element
is a string containing the portion of \fIstring\fR that matched \fIexp\fR.
Additional list elements correspond to the portion of \fIstring\fR that
matched a parenthesized subexpression of \fIexp\fR.
Note that if \fB\-eval\fR is used then the \fIsubSpec\fR is just normal
Tcl code; the special \fBnresub\fR characters ``&'' and ``\e\fIn\fR''
are treated normally.
.VS
If \fBreturn\fR is executed during the evaluation then the returned
value used to replace the text matched by the regular expression.
.VE
If \fBbreak\fR is executed during the evaluation then \fBnresub\fR
acts as if the current match did not happen and that no more matches
occur in \fIstring\fR. If \fBcontinue\fR is executed during the evaluation
then \fBnresub\fR acts as if the current match did not happen and
continues on looking for matches in the rest of \fIstring\fR.
If an error occurs during the evaluation then 
\fBnresub\fR does not set \fIvarName\fR.
The list value of \fIevalName\fR will only contain as many elements as
the \fIexp\fR has subexpressions. Note that if the \fIexp\fR has more than
nine subexpressions then \fB\-eval\fR is the only way to access them
from the \fIsubSpec\fR.
.TP 10
\fB\-\|\-\fR
Marks the end of switches.  The argument following this one will
be treated as \fIexp\fR even if it starts with a \fB\-\fR.
.PP
The command returns a count of the number of matching ranges that
were found and replaced.
See the man page for \fBnrematch\fR for details on the interpretation
of regular expressions.

.SH SUBSPEC SYNTAX
.PP
If the \fB\-eval\fR switch is used then the \fIsubSpec\fR is evaluated
as normal Tcl code. See the description of the \fB\-eval\fR switch
for details. Otherwise 
if \fIsubSpec\fR contains a ``&'' or ``\e0'', then it is replaced
in the substitution with the portion of \fIstring\fR that
matched \fIexp\fR.
If \fIsubSpec\fR contains a ``\e\fIn\fR'', where \fIn\fR is a digit
between 1 and 9, then it is replaced in the substitution with
the portion of \fIstring\fR that matched the \fIn\fR-th
parenthesized subexpression of \fIexp\fR.
Additional backslashes may be used in \fIsubSpec\fR to prevent special
interpretation of ``&'' or ``\e0'' or ``\e\fIn\fR'' or
backslash.
The use of backslashes in \fIsubSpec\fR tends to interact badly
with the Tcl parser's use of backslashes, so it's generally
safest to enclose \fIsubSpec\fR in braces if it includes
backslashes.

.SH KEYWORDS
match, nre, pattern, regular expression, substitute
