# nre.tcl --
#
#       The nre package provides a new regular expression engine.
#       Its standard commands are: nreuse, nrematch, nresub,
#       nrelsearch, nreswitch, and nredump.
#
# See the file "license.terms" for information on usage and
# redistribution of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

# nreuse
# If flag is true then the  nre commands will replace the standard
# commands: regexp, regsub, lsearch, switch.
# If flag is false then the standard commands are restored.
#
proc nreuse {flag} {
    if {$flag} {
	if {[info commands nredump] == {}} {
	    # auto load has not been done
	    auto_load nredump
	}
	if {[info commands builtin_regexp] == {}} {
	    rename regexp builtin_regexp
	    rename nrematch regexp
	    interp alias {} nrematch {} regexp
	    rename regsub builtin_regsub
	    rename nresub regsub
	    rename lsearch builtin_lsearch
	    rename nrelsearch lsearch
	    rename switch builtin_switch
	    rename nreswitch switch
	}
    } else {
	if {[info commands builtin_regexp] != {}} {
	    interp alias {} nrematch {}
	    rename regexp nrematch
	    rename builtin_regexp regexp 
	    rename regsub nresub
	    rename builtin_regsub regsub
	    rename lsearch nrelsearch
	    rename builtin_lsearch lsearch
	    rename switch nreswitch
	    rename builtin_switch switch
	}
    }
    return
}

# nresplit is just like the standard Tcl split command except the
# splitting is done using a regular expression instead of split's
# splitChars.
proc nresplit {string {regexp {(?p)\s}}} {
    if {$regexp == {}} {
	return [split $string {}]
    }

    nrematch -split $regexp $string res
    return $res
}

# nreforeach is much like the standard Tcl foreach command except 
# elements iterated over are determined by a regular expression.
proc nreforeach {varname regexp string body} {
    uplevel [list nrematch -eval -all -flatten $regexp $string $varname $body]
    return
}
